\name{NatSizeDist}
\alias{NatSizeDist}
\title{
Reveal the estimates of Ne
}
\description{
Calculates estimates of effective size (Ne) at a number of times from 0 to a certain time ago (given by the user), plots and saves results on files.
}
\usage{
NatSizeDist(NameBATCH = NULL, MUTAT = NULL, TMAX = NULL, NBT = NULL)
}
\arguments{

  \item{NameBATCH}{[matrix]:File .Batch create by the function VarEff
}
  \item{MUTAT}{[numeric]:Mutation rate
}
  \item{TMAX}{[integer]:Length of the period for which the distributions of Ne or Log(Ne) in the past are generated
}
  \item{NBT}{[integer]:Number of time intervals. 
  
Example: If TMAX=1000 generations, and NBT=100, the estimates are calculated every 10th generation until 1000 generations ago
}
}
\details{
Results can be shown in natural census values of population sizes, or in reduced theta scale if mutation rate is set to 0 in these functions.

To obtain the distribution of Log10(Ne) at a number of generations in the past, run the function  LogSizeDist().

Both functions work the same. They use the job.Batch file created by VarEff().\cr 


Nstat file:

Column  1: Time in generations (if MUTAT is not 0) or the corresponding reduced time.

Columns 2: Arithmetic Mean of Ne.

Columns 3: Harmonic means of Ne (not provided by LogSizeDist() for Log10(Ne)).

Columns 4: Mode of Ne.

Columns 5: Median of Ne.

Columns 6: Quantile 5 percent of Ne.

Columns 7: Quantile 95 percent of Ne.

Column 8: Standard deviation of Ne. \cr


Ndist file: 

Posterior densities of Ne or Log(Ne) at past times (fitted distribution using the density R function).

File with  (Nbinstants+1) lines and 514 columns.

Lines: Instants when the distribution of N(T(i-1)) was calculated. 1 <= i <= NBT+1, 0 <= T(i-1) <= TMAX

- TMAX (Length of the period for which the distributions of Ne in the past are generated).

- NBT (Number of time intervals. Example: If TMAX=1000 generations, and NBT=100, estimates are calculated every 10th generation until 1000 generations ago).

Columns in line i:

Column  1: Values of  T(i-1).
 
Columns 2: interval between two N abscissa of the distribution 
 
Columns 3 to 514: Ordinates (densities of 512 Ne values).  \cr


Nsize file:

A file giving the Nbatch series of population size values N(0), N(1)  ... N(NBT), 
it is a matrix with as many lines as simulated states (NumberBatch parameter) and NBT+1 columns.  \cr

}
\value{
\item{job.Nstat}{Summary statistics of posterior effective population size. Matrix(ncol=7,nrow=generation time): 
Time in generations, Arithmetic mean of Ne, Harmonic mean of Ne, Mode of Ne, Median of Ne, Quantile 5 percent of Ne, Quantile 95 percent of Ne.}
\item{job.Ndist}{Containing the detailed densities of the posterior distributions of Ne.}
\item{job.Nsize}{Containing the values of Ne generated by the Nbatch simulations at NBT+1 times.}
}
\references{
Nikolic N., Chevalet C. 2014. Detecting past changes of effective population size. Evolutionary Applications, 7(6):663-81. \cr

Chevalet C., Nikolic N. 2010. Distribution of coalescent times and distances between microsatellite alleles with changing effective population size. Theoretical Population Biology, 77(3): 152-163.  
}
\author{
Natacha Nikolic <documents_57@hotmail.com> and Claude Chevalet <claude.chevalet@toulouse.inra.fr>
}
\note{
More details on the model can be found on the website: \url{https://qgsp.jouy.inra.fr}
}
\seealso{
Overview: \code{\link{VarEff-package}} \cr
Exemple: \code{\link{InputTest}} \cr
HelpData: \code{\link{HelpData}} 
}
\examples{
library(VarEff)
NatSizeDist (NameBATCH = system.file("extdata/job.Batch", package = "VarEff") 
, MUTAT = 0.01, TMAX = 200, NBT = 10) 
}
\keyword{ models }