\name{Theta}
\alias{Theta}
\title{
Preliminary analysis of data to choose Theta priors and DMAX from microsatellites data
}
\description{
This function allows to get global Theta (4*Ne*u) using 3 estimators correlated to the mean of
Present (Theta_0), Intermediate (Theta_1) and Ancestral (Theta_2) population sizes.

The results are written to a .Thet0 file. 

It is also provide Imbalance indices ln(Theta_1/Theta_0) and ln(Theta_2/Theta_0),
then the minimum of census Ne (Ne0=Theta_0/4*u) and the maximum Ne (Ne_2=Theta_2/4*u).  \cr

Values of .Thet0 file:
Theta_0, Theta_1, Theta_2
Imbalance indices ln(Theta_1/Theta_0) and ln(Theta_2/Theta_0)
MinNe, MaxNe
 \cr
These results provide an overview of priors necessary for VarEff function.

The programm also allows one to build a file .R to process the model VarEff with the function VarEff(). \cr
}
\usage{
Theta(parafile = NULL,infile  = NULL, NBLOC = NULL, JMAX = NULL, 
MODEL = NULL, MUTAT = NULL, NBAR = NULL, VARP1 = NULL, RHOCORN = NULL, 
GBAR = NULL, VARP2 = NULL, DMAXPLUS = NULL, Diagonale = NULL, NumberBatch = NULL,
 LengthBatch = NULL, SpaceBatch = NULL, Burnin = NULL, AccRate = NULL)
}
\arguments{
  \item{parafile}{[character]:job name
}
  \item{infile}{[character]:Input data
}
  \item{NBLOC}{[integer]:Number of markers
}
  \item{JMAX}{[integer]:Number of time that the effective size has changed
}
  \item{MODEL}{[numeric]:Mutation model
}
  \item{MUTAT}{[numeric]:Mutation rate
}
  \item{NBAR}{[integer]:Global mean of effective size
}
  \item{VARP1}{[integer]:Variance of the prior log-distribution of effective sizes
}
  \item{RHOCORN}{[numeric]:Coefficient of correlation between effective sizes
}
  \item{GBAR}{[integer]:Number of generations since the origin of the population
}
  \item{VARP2}{[integer]:Variance of the prior log-distribution of time intervals
}
  \item{Diagonale}{[numeric]:A smoothing parameter to balance the observed covariance structure with a theoretical diagonal variance 
}
  \item{DMAXPLUS}{[integer]:Range of allele distances to be analysed
}
  \item{NumberBatch}{[integer]:number of batch (nbatch) for metrop in MCMC
}
  \item{LengthBatch}{[integer]:length of batch (blen) for metrop in MCMC
}
  \item{SpaceBatch}{[integer]:space between batch outputs (nspac) for metrop in MCMC
}
  \item{Burnin}{[integer]:number of preliminary simulations, to get equilibrium distributions
}
  \item{AccRate}{[integer]:the acceptation rate used to select valuable states
}

}
\details{
This function provides:
 \cr
-Global Theta0, Theta1 and Theta2 estimates, with Theta0 (mean of current Theta(4*Ne*u)), Theta1 (mean of intermediate Theta), Theta2 (mean of ancestral Theta).

-Imbalance indices ln(Theta1/Theta0) and ln(Theta2/Theta0).

-Expected range of Ne values, from the minimum and maximum global Theta estimates.
 \cr
Secondly, the Theta file provides the realized acceptation rate, means, and standard deviations over simulations of the quadratic deviations of data from simulated state and of natural logarithm of the prior probabilities of the simulated states. 
 \cr
It also builds a script to run VarEff (job.R).
\cr

}
\value{
\item{job.Thet0}{File with global preliminary statistics}
\item{job.R}{script to run VarEff with the chosen parameters}
}
\references{
Nikolic N., Chevalet C. 2014. Detecting past changes of effective population size. Evolutionary Applications, 7(6):663-81.
Chevalet C., Nikolic N. 2010. Distribution of coalescent times and distances between microsatellite alleles with changing effective population size. Theoretical Population Biology, 77(3): 152-163.  
}
\author{
Natacha Nikolic <documents_57@hotmail.com> and Claude Chevalet <claude.chevalet@toulouse.inra.fr>
}
\note{
More details on the model can be found on the website: \url{https://qgsp.jouy.inra.fr}
}
\seealso{
Overview: \code{\link{VarEff-package}} \cr
Exemple: \code{\link{InputTest}} \cr
HelpData: \code{\link{HelpData}} 
}
\examples{
library(VarEff)
Theta (infile=system.file("data/InputTest.txt", package = "VarEff"),
parafile = 'job',
       NBLOC=20,
       JMAX=3,
       MODEL = 'S',
       MUTAT=0.01,
       NBAR=1000,
       VARP1=3,
       RHOCORN=0,
       GBAR=5000,
       VARP2=3,
       DMAXPLUS=12,
       Diagonale=0.5,
       NumberBatch = 100,
       LengthBatch = 10,
       SpaceBatch = 10,
       Burnin = 100,
       AccRate = 0.25) 
}
\keyword{ priors }